
	processor 6502
	include vcs.h
	include macro.h
	
	
;-------------------------Constants Below---------------------------------

COLOR1	=	RED+10
COLOR2	=	BLUE2+12
COLOR3	=	GREEN+10




ROWHEIGHT	=	24
NUMROWS	=	7

MAXMAPWIDTH	=	48
MAXMAPDEPTH	=	42

PLAYERHEIGHT	=	24
;-------------------------COLOR CONSTANTS (NTSC)--------------------------

GRAY		=	$00
GOLD		=	$10
ORANGE		=	$20
BURNTORANGE	=	$30
RED		=	$40
PURPLE		=	$50
PURPLEBLUE	=	$60
BLUE		=	$70
BLUE2		=	$80
LIGHTBLUE	=	$90
TURQUOISE	=	$A0
GREEN		=	$B0
BROWNGREEN	=	$C0
TANGREEN	=	$D0
TAN		=	$E0
BROWN		=	$F0

;--------------------------TIA CONSTANTS----------------------------------

	;--NUSIZx CONSTANTS
	;	player:
ONECOPYNORMAL		=	$00
TWOCOPIESCLOSE		=	$01
TWOCOPIESMED		=	$02
THREECOPIESCLOSE	=	$03
TWOCOPIESWIDE		=	$04
ONECOPYDOUBLE		=	$05
THREECOPIESMED		=	$06
ONECOPYQUAD		=	$07
	;	missile:
SINGLEWIDTHMISSILE	=	$00
DOUBLEWIDTHMISSILE	=	$10
QUADWIDTHMISSILE	=	$20
OCTWIDTHMISSILE		=	$30

	;---CTRLPF CONSTANTS
	;	playfield:
REFLECTEDPF		=	%00000001
SCOREPF			=	%00000010
PRIORITYPF		=	%00000100
	;	ball:
SINGLEWIDTHBALL		=	SINGLEWIDTHMISSILE
DOUBLEWIDTHBALL		=	DOUBLEWIDTHMISSILE
QUADWIDTHBALL		=	QUADWIDTHMISSILE
OCTWIDTHBALL		=	OCTWIDTHMISSILE

	;---HMxx CONSTANTS
LEFTSEVEN		=	$70
LEFTSIX			=	$60
LEFTFIVE		=	$50
LEFTFOUR		=	$40
LEFTTHREE		=	$30
LEFTTWO			=	$20
LEFTONE			=	$10
NOMOVEMENT		=	$00
RIGHTONE		=	$F0
RIGHTTWO		=	$E0
RIGHTTHREE		=	$D0
RIGHTFOUR		=	$C0
RIGHTFIVE		=	$B0
RIGHTSIX		=	$A0
RIGHTSEVEN		=	$90
RIGHTEIGHT		=	$80

	;---AUDCx CONSTANTS (P Slocum's naming convention)
SAWSOUND		=	1
ENGINESOUND		=	3
SQUARESOUND		=	4
BASSSOUND		=	6
PITFALLSOUND		=	7
NOISESOUND		=	8
LEADSOUND		=	12
BUZZSOUND		=	15

	;---SWCHA CONSTANTS (JOYSTICK)
J0RIGHT		=	%10000000
J0LEFT		=	%01000000
J0DOWN		=	%00100000
J0UP		=	%00010000
J1RIGHT		=	%00001000
J1LEFT		=	%00000100
J1DOWN		=	%00000010
J1UP		=	%00000001

	;---SWCHB CONSTANTS (CONSOLE SWITCHES)
P1DIFF		=	%10000000
P0DIFF		=	%01000000
BWCOLOR		=	%00001000
SELECT		=	%00000010
RESET		=	%00000001

;-------------------------End Constants-----------------------------------

	
;-------------------------MACROS------------------------------------------


	MAC FILLER
		REPEAT {1}
			.byte {2}
		REPEND
	ENDM

	SEG.U VARS
	ORG $80

; Supercharger Bank Config
SCSave		ds 2

;--game zero-page vars

Counter ds 1

PlayerX ds 1		;absolute screen coordinates
PlayerY ds 1

PlayerDataPtr ds 2
PlayerMaskPtr ds 2

OtherSpritePtr ds 2
OtherMaskPtr ds 2

MiscPtr ds 2

OtherSpriteRowNew ds 1
OtherSpriteRowOld ds 1

;--displayed room coords (upper left tile)
RoomX ds 1
RoomY ds 1

RowNumberSaver ds 1

PtrTemp ds 2
Temp ds 5

	; Display Remaining RAM
	echo "----",($100 - *) , "bytes left (ZP RAM)" 
	
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
;--------------------------BANK THREE---------------------------------------
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------

	; Bank 3
	SEG	BANK3
	ORG	$0000,0
	RORG	$1000,0

	; Don't Execute Code Here with Write Enabled
	nop
	
	ORG	$0100,0
	RORG	$1100,0
Start
        ; Wipe Registers & Memory
	CLEAN_START        
	
	;--any initial setup goes here
	
	lda #REFLECTEDPF
	sta CTRLPF
	
	;--get everything at the left edge
	sta WSYNC
	sta RESP0
	sta RESP1
	sta RESM0
	sta RESM1
	sta RESBL

	lda #$11
	sta PlayerMaskPtr+1
	sta OtherMaskPtr+1

	lda #$0E
	sta COLUP0
	sta COLUP1

	lda #ONECOPYDOUBLE
	sta NUSIZ1
	sta NUSIZ0

	lda #1
	sta VDELP1

	lda #40
	sta PlayerX
	sta PlayerY

	;--initial screen setup

	lda #100
	sta T1024T
	ldx #NUMROWS-1
	jsr SetupTileDisplaySubroutine


	
;-------------------------------------------------------------------------
;--------------GAME MAIN LOOP---------------------------------------------
;-------------------------------------------------------------------------

MainGameLoop

	jsr VBLANKRoutine
	jsr KernelRoutine
	jsr OverscanRoutine
	jmp MainGameLoop

;-------------------------------------------------------------------------
;-------------------VBLANK Routine----------------------------------------
;-------------------------------------------------------------------------

VBLANKRoutine
	lda #%00001111
VSYNCLoop
	sta WSYNC
	sta VSYNC
	lsr
	bcs VSYNCLoop

	lda #43
	sta TIM64T

	dec Counter

	lda Counter
	lsr
	bcc DoNotSetupTileDisplayThisFrame
	ldx RowNumberSaver
	bmi DoNotSetupTileDisplayThisFrame
	jsr SetupTileDisplaySubroutine




	jmp WaitForVblankEnd
DoNotSetupTileDisplayThisFrame

	jsr FinishSetupTileDisplaySubroutine
	jsr SetupOtherSpriteSubroutine
	jsr SetupPlayerSpriteSubroutine





WaitForVblankEnd
	lda INTIM
	bne WaitForVblankEnd

	sta WSYNC
	sta VBLANK	;turn off VBLANK - it was turned on by overscan

	rts

;-------------------------------------------------------------------------
;----------------------Kernel Routine-------------------------------------
;-------------------------------------------------------------------------

;	align 256

KernelRoutine

	
	ldy #ROWHEIGHT*NUMROWS
	ldx #ROWHEIGHT-1
	sta WSYNC
	SLEEP 5
KernelLoop1
	sta GRP0		;+3	 8
	SLEEP 5		;+5	13

	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR1PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR1PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR1PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR1PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR1
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1					;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y		;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop1		;+5	 5

	ldx #ROWHEIGHT-1		;+2	 6
	bne IntoKernelLoop2	;+3	 9	branch always
KernelLoop2
	SLEEP 4		;+4	 9
IntoKernelLoop2
	sta.w GRP0		;+4	13


	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR2PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR2PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR2PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR2PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR2
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop2		;+5	 5

	ldx #ROWHEIGHT-1		;+2	 6
	jmp IntoKernelLoop3	;+3	 9	branch always

	align 256
	
KernelLoop3
	SLEEP 4		;+4	 9
IntoKernelLoop3
	sta.w GRP0		;+4	13


	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR3PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR3PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR3PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR3PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR3
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop3		;+5	5
	
	ldx #ROWHEIGHT-1		;+2	 6
	bne IntoKernelLoop4	;+3	 9	branch always
KernelLoop4
	SLEEP 4		;+4	 9
IntoKernelLoop4
	sta.w GRP0		;+4	13


	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR4PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR4PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR4PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR4PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR4
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop4		;+5	5
	
	ldx #ROWHEIGHT-1		;+2	 6
	jmp IntoKernelLoop5	;+3	 9	branch always

	align 256

KernelLoop5
	SLEEP 4		;+4	 9
IntoKernelLoop5
	sta.w GRP0		;+4	13


	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR5PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR5PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR5PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR5PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR5
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop5		;+5	 5
	
	ldx #ROWHEIGHT-1		;+2	 6
	bne IntoKernelLoop6	;+3	 9	branch always
KernelLoop6
	SLEEP 4		;+4	 9
IntoKernelLoop6
	sta.w GRP0		;+4	13


	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR6PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR6PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR6PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR6PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR6
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+12/14	60/62	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop6		;+5	 5
	
	ldx #ROWHEIGHT-1		;+2	 6
	bne IntoKernelLoop7	;+3	 9	branch always
KernelLoop7
	SLEEP 4		;+4	 9
IntoKernelLoop7
	sta.w GRP0		;+4	13

	lda ColorTable,X
	sta COLUPF		;+7	20

MarkerR7PF1
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR7PF2
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2
MarkerR7PF4
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF1
MarkerR7PF3
	lda $1800,X		;		this absolute address is modified outside the kernel
	sta PF2			;+28	48

MarkerOtherSpriteR7
	lda PlayerMaskingData,X		;		this absolute address is modified outside the kernel
	sta GRP1			;+7/8		55/56	VDELed
	lda (PlayerDataPtr),Y		;
	and (PlayerMaskPtr),Y	;+10/12	65/68
	dey
	sta WSYNC
	
	dex
	bpl KernelLoop7		;+5	 5

DoneWithKernel

	lda #0
	sta PF1
	sta PF2
	sta GRP0
	sta GRP1

	;--text area of kernel:
	ldy #24
TextKernelLoop
	sta WSYNC
	dey
	bne TextKernelLoop

	rts

;-------------------------------------------------------------------------
;------------------------Overscan Routine---------------------------------
;-------------------------------------------------------------------------

OverscanRoutine




	lda #2
	sta WSYNC
	sta VBLANK	;turn on VBLANK
	lda  #32
	sta  TIM64T


	;--main thing that needs to be accomplished here is to modify all the absolute
	;	addresses in the kernel so that we are displaying the proper tiles.
	;	This will probably take up most of the overscan.
	
	lda Counter
	lsr
	bcs DoNotSetupTileDisplayThisFrameOverscan
	jsr ReadJoystickSubroutine

	ldx #NUMROWS-1
	jsr SetupTileDisplaySubroutine
DoNotSetupTileDisplayThisFrameOverscan

	

WaitForOverscanEnd
	lda INTIM
	bpl WaitForOverscanEnd
	rts

;-------------------------------------------------------------------------
;----------------------------End Main Routines----------------------------
;-------------------------------------------------------------------------


;*************************************************************************

;-------------------------------------------------------------------------
;----------------------Begin Subroutines----------------------------------
;-------------------------------------------------------------------------

SetupPlayerSpriteSubroutine
	;--vertically position player
	;--two parts: one, setup data ptr.  Two, setup mask ptr.  Easy pizza.
	;---(remember to do 16-bit addition/subtraction!)

	lda #<EndPlayerFrame1		;--static graphic for now
	sta PlayerDataPtr
	lda #>EndPlayerFrame1
	sta PlayerDataPtr+1

	lda PlayerDataPtr
	sec
	sbc PlayerY
	sta PlayerDataPtr
	lda PlayerDataPtr+1
	sbc #0
	sta PlayerDataPtr+1

	lda #<EndOfPlayerMask
	sta PlayerMaskPtr
	lda #>EndOfPlayerMask
	sta PlayerMaskPtr+1

	lda PlayerMaskPtr
	sec
	sbc PlayerY
	sta PlayerMaskPtr
	lda PlayerMaskPtr+1
	sbc #0
	sta PlayerMaskPtr+1	


	;--horizontally position player
	lda PlayerX
	ldx #0
	jsr PositionASpriteSubroutine


	rts

;-------------------------------------------------------------------------

FinishSetupTileDisplaySubroutine

	ldx #54
CopyNewTileAddressesLoop
	stx Temp

	;--find address to write to
	lda TilePtrAddressesLookup,X
	sta MiscPtr
	lda TilePtrAddressesLookup+1,X
	sta MiscPtr+1

	;--find values to write
	lda NewTileAddresses,X
	sta Temp+1
	lda NewTileAddresses+1,X
	sta Temp+2

	ldx Temp+1
	ldy #0
	nop $1000,X
	cmp (MiscPtr),Y
	ldx Temp+2
	iny
	nop $1000,X
	cmp (MiscPtr),Y
	ldx Temp
	dex
	dex	
	bpl CopyNewTileAddressesLoop

	rts

;-------------------------------------------------------------------------

PositionASpriteSubroutine
	sta HMCLR
	sec
	sta WSYNC
DivideLoop
	sbc #15
	bcs DivideLoop	;+4	 4
	eor #7
	asl
	asl
	asl
	asl			;+10	14
	sta.wx HMP0,X	;+5	19
	sta RESP0,X		;+4	23
	sta WSYNC
	sta HMOVE


	rts

;-------------------------------------------------------------------------

SetupOtherSpriteSubroutine
	;--first: find new sprite


	lda RoomY		;top row
	tax
	clc
	adc #7		;bottom row plus one
	sta Temp

	lda RoomX		;left column
	sta Temp+1
	clc
	adc #8
	sta Temp+2		;right column (plus one)
FindOtherSpriteLoop
	lda OtherSpriteX,X
	cmp Temp+1
	bcc OtherSpriteNotOnscreen
	cmp Temp+2
	bcc FoundOtherSprite
OtherSpriteNotOnscreen
	inx
	cpx Temp
	bne FindOtherSpriteLoop
	lda #$FF
	sta OtherSpriteRowNew		;this means no other sprite on screen. :)
	jmp NoOtherSpriteOnscreen

FoundOtherSprite
	;--X holds row number
	txa
	sec
	sbc RoomY			;we want relative row number, duh.
	sta OtherSpriteRowNew

NoOtherSpriteOnscreen

	;---PART TWO
	;--first, erase old sprite
	;--second, draw new sprite
	;--third, horizontally position new sprite
	;--fourth, write OtherSpriteRowNew to OtherSpriteRowOld


	;--erase old sprite
	lda OtherSpriteRowOld	;--relative row number stored in OtherSpriteRow (0 through 6)
	asl
	tax
	lda OtherSpriteRowLookupTable,X
	sta MiscPtr
	lda OtherSpriteRowLookupTable+1,X
	sta MiscPtr+1
	ldy #0
	;--erase
	nop $1000+<PlayerMaskingData
	cmp (MiscPtr),Y
	iny
	nop $1000+>PlayerMaskingData
	cmp (MiscPtr),Y


	;--draw new sprite
	lda OtherSpriteRowNew	;--relative row number
	bmi NoOtherSpriteOnScreen
	asl
	tax
	lda OtherSpriteRowLookupTable,X
	sta MiscPtr
	lda OtherSpriteRowLookupTable+1,X
	sta MiscPtr+1
	lda OtherSpriteRowNew
	clc
	adc RoomY
	sta Temp			;absolute row number
	tay
	lda OtherSpriteType,Y
	tay
	ldx OtherSpriteGfxLo,Y
	ldy #0
	nop $1000,X
	cmp (MiscPtr),Y
	ldy Temp
	lda OtherSpriteType,Y
	tay
	ldx OtherSpriteGfxHi,Y
	ldy #1
	nop $1000,X
	cmp (MiscPtr),Y

	;--horizontally position new sprite
	;horizontal position equals [(absolute column-leftmost column)*16] + constant
	;	where absolute value is the column number from a table
	;		constant is 15, I think.
	ldx Temp			;absolute row number
	lda OtherSpriteX,X	;absolute column number
	sec
	sbc RoomX			;relative column number (should be #0 through #3)
	asl
	asl
	asl
	asl				;times sixteen
	clc
	adc #15
	ldx #1
	jsr PositionASpriteSubroutine

	;--update tracking vars (relative row numbers)
	lda OtherSpriteRowNew
	sta OtherSpriteRowOld
NoOtherSpriteOnScreen
	rts
	
;-------------------------------------------------------------------------

ReadJoystickSubroutine
	lda SWCHA
	sta Temp
	and #J0UP
	bne NoUp
	dec RoomY
NoUp
	lda Temp
	and #J0DOWN
	bne NoDown
	inc RoomY
NoDown
	lda Temp
	and #J0LEFT
	bne NoLeft
	dec RoomX
NoLeft
	lda Temp
	and #J0RIGHT
	bne NoRight
	inc RoomX
NoRight


	;check boundaries!
	lda RoomY
	bpl RoomYNotTooSmall
	inc RoomY
RoomYNotTooSmall
	lda RoomY
	cmp #MAXMAPDEPTH-6
	bcc RoomYNotTooBig
	dec RoomY
RoomYNotTooBig
	lda RoomX
	bpl RoomXNotTooSmall
	inc RoomX
	lda RoomX
RoomXNotTooSmall
	cmp #MAXMAPWIDTH-7
	bcc RoomXNotTooBig
	dec RoomX
RoomXNotTooBig

	rts

;-------------------------------------------------------------------------

;	align 256

SetupTileDisplaySubroutine
	;--starting row number in X
	stx Temp+2
SetupTileAddressesOuterLoop
	lda #3		;column number (0=PF1, 1=PF2, 2=PF3, 3=PF4)
	sta Temp+3

	;--get addy of left tile and save it:
	lda RoomY
	clc
	adc Temp+2			;adjust for row we are working on
	asl
	tay
	lda RoomX
	lsr
	clc
	adc TileRowLookupTable,Y	;add roomX divided by 2.
	sta PtrTemp
	lda TileRowLookupTable+1,Y
	sta PtrTemp+1


SetupTileAddressesInnerLoop	
	ldy #0
	;--find tile-pair

	;--note: two routines: one if RoomX is odd (get left tile from 1 byte, other tile from
	;		next byte) another if RoomY is even (get both tiles from 1 byte)

	;--adjust for column we are on.
	dec PtrTemp
	;--now, adjust for row we are on

	lda RoomX
	lsr
	bcc GetTilesOnEvenBoundary
	;--else get tiles on an odd boundary
	;--Y is zero already
	lda (PtrTemp),Y
	and #$0F				;get left tile
	tax
	lda TimesSixteenTable,X		;...times 16...
	sta Temp
	iny
	lda (PtrTemp),Y
	and #$F0
	lsr
	lsr
	lsr			;...plus right tile * 2.
HaveTileBitmapIndex
	adc Temp		;(carry is clear after LSR)
	tay			;Is our index into the array of tile bitmaps.

	;--if column is 0 or 2, we want normal tiles
	;	else, reversed
	lda Temp+3		;column stored in here
	lsr
	bcs GetReversedTileBitmaps
	lda NormalTileTable,Y
	sta Temp
	lda NormalTileTable+1,Y
GotTileBitmapAddress
	tax		;put value in X

	;--now, Temp holds low byte of address to bitmap; X holds high byte.

	;--so, we have the address for the bitmap - now let's write it to the right spot
	;---Scratch that!  New method: write all new addresses to memory
	;	and then copy them to the kernel all at once ;)
;	ldy Temp+3
;	lda Temp+2
;	asl
;	clc
;	adc TimesSixteenTable,Y
;	
;	tay
;	lda TilePtrAddressesPF1,Y
;	sta MiscPtr
;	lda TilePtrAddressesPF1+1,Y
;	sta MiscPtr+1

	;--correct address is: [NewTileAddresses+row*8+column*2]
	
	lda Temp+2		;row #
	asl
	asl
	asl			;times eight
	sta Temp+4
	lda Temp+3		;plus column number
	asl			;times two
	clc
	adc Temp+4
	tay
	iny			;writing high byte first
	;--now, write to SC RAM! (high byte first so that Y = 0 when we are done)
	;--X already holds correct value
	nop $1000,X
	nop
	cmp NewTileAddresses,Y	;write new high byte.
	dey
	ldx Temp		;load new low byte
	nop $1000,X
	nop
	cmp NewTileAddresses,Y	;write new low byte.

	
	;and...we're done.  Next column!
	dec Temp+3
	bpl SetupTileAddressesInnerLoop

	lda INTIM
	cmp #10
	bcc AllDoneWithTileAddressesLoop
	dec Temp+2		;decrement row #
	bpl SetupTileAddressesOuterLoop

AllDoneWithTileAddressesLoop
	dec Temp+2
	lda Temp+2
	sta RowNumberSaver
	
	rts

GetTilesOnEvenBoundary
	;	Y is zero already
	lda (PtrTemp),Y	;<--have both tiles
	sta Temp+1
	and #$F0		;left tile * 16...
	sta Temp
	lda Temp+1		;...plus right tile
	and #$0F
	asl
	;...times two. (carry is clear after ASL)
	jmp HaveTileBitmapIndex

GetReversedTileBitmaps
	lda ReversedTileTable,Y
	sta Temp
	lda ReversedTileTable+1,Y
	jmp GotTileBitmapAddress


;*************************************************************************

;-------------------------------------------------------------------------
;-------------------------Data Below--------------------------------------
;-------------------------------------------------------------------------





OtherSpriteRowLookupTable
	.word MarkerOtherSpriteR1+1,MarkerOtherSpriteR2+1,MarkerOtherSpriteR3+1,MarkerOtherSpriteR4+1
	.word MarkerOtherSpriteR5+1,MarkerOtherSpriteR6+1,MarkerOtherSpriteR7+1

	align 2

NewTileAddresses ds 56,$18		;the routine takes too long to figure and write
					;all these addresses, so I'll write them all here instead
					;and then very quickly (I hope!) copy them to the kernel

PlayerMaskingData			;note: might need two of these tables, one
					;	for when the sprite is in the top half of the screen
					;	and one for when the sprite is in the bottom half.
	FILLER (ROWHEIGHT*(NUMROWS-1)), 0
	FILLER ROWHEIGHT,$FF
EndOfPlayerMask
	FILLER (ROWHEIGHT*(NUMROWS-1)), 0



PlayerFrame1
	.byte 0
        .byte #%01111110;--
        .byte #%00111100;--
        .byte #%00111100;--
        .byte #%00111000;--
        .byte #%00110000;--
        .byte #%01100110;--
        .byte #%01101111;--
        .byte #%01101111;--
        .byte #%01101001;--
        .byte #%01101111;--
        .byte #%01101111;--
        .byte #%01100000;--
        .byte #%00111100;--
        .byte #%00111100;--
        .byte #%00011000;--
        .byte #%00111100;--
        .byte #%00111100;--
        .byte #%00111100;--
        .byte #%01111110;--
        .byte #%01011010;--
        .byte #%01000010;--
        .byte #%01000010;--
EndPlayerFrame1




TimesSixteenTable
	.byte 0,16,32,48
	.byte 64,80,96,112
	.byte 128,144,160,176
	.byte 192,208,224,240


	;--note: these address are the actual address of the low byte
;TilePtrAddressesPF1
;	.word MarkerR1PF1+1,MarkerR2PF1+1,MarkerR3PF1+1,MarkerR4PF1+1,MarkerR5PF1+1,MarkerR6PF1+1,MarkerR7PF1+1,0
;TilePtrAddressesPF2
;	.word MarkerR1PF2+1,MarkerR2PF2+1,MarkerR3PF2+1,MarkerR4PF2+1,MarkerR5PF2+1,MarkerR6PF2+1,MarkerR7PF2+1,0
;TilePtrAddressesPF3
;	.word MarkerR1PF3+1,MarkerR2PF3+1,MarkerR3PF3+1,MarkerR4PF3+1,MarkerR5PF3+1,MarkerR6PF3+1,MarkerR7PF3+1,0
;TilePtrAddressesPF4
;	.word MarkerR1PF4+1,MarkerR2PF4+1,MarkerR3PF4+1,MarkerR4PF4+1,MarkerR5PF4+1,MarkerR6PF4+1,MarkerR7PF4+1,0

TilePtrAddressesLookup
	.word MarkerR1PF1+1,MarkerR1PF2+1,MarkerR1PF3+1,MarkerR1PF4+1
	.word MarkerR2PF1+1,MarkerR2PF2+1,MarkerR2PF3+1,MarkerR2PF4+1
	.word MarkerR3PF1+1,MarkerR3PF2+1,MarkerR3PF3+1,MarkerR3PF4+1
	.word MarkerR4PF1+1,MarkerR4PF2+1,MarkerR4PF3+1,MarkerR4PF4+1
	.word MarkerR5PF1+1,MarkerR5PF2+1,MarkerR5PF3+1,MarkerR5PF4+1
	.word MarkerR6PF1+1,MarkerR6PF2+1,MarkerR6PF3+1,MarkerR6PF4+1
	.word MarkerR7PF1+1,MarkerR7PF2+1,MarkerR7PF3+1,MarkerR7PF4+1

;-------------------------------------------------------------------------
;-------------------------End Data----------------------------------------
;-------------------------------------------------------------------------


;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
;--------------------------BANK ONE---------------------------------------
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
			
	; Bank 1 (2K)
	SEG	BANK1
	ORG	$0800,0
	RORG	$1800,0
	
	
	
;-------------------------------------------------------------------------
;-------------------------Data Below--------------------------------------
;-------------------------------------------------------------------------
	
	align 256
	
TileMap
TileMapRow1
	.byte $11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11
TileMapRow2
	.byte $11,$11,$11,$11,$11,$11,$11,$11,$11,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow3
	.byte $11,$11,$11,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow4
	.byte $11,$11,$10,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow5
	.byte $11,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow6
	.byte $11,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow7
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$11,$11,$11,$11,$00,$00,$00,$00,$00,$00,$01
TileMapRow8
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$01
TileMapRow9
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$00,$00,$00,$01,$11,$11,$11,$11,$11,$00,$01
TileMapRow10
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11

	align 256

TileMapRow11
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow12
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow13
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow14
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow15
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01
TileMapRow16
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$00,$00,$00,$00,$01
TileMapRow17
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$00,$00,$00,$00,$01
TileMapRow18
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$00,$00,$00,$00,$01
TileMapRow19
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$11,$00,$00,$00,$01
TileMapRow20
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$11,$11,$11,$11,$10,$00,$01

	align 256

TileMapRow21
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$11,$11,$10,$00,$01
TileMapRow22
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$11,$11,$11,$11,$10,$01
TileMapRow23
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$01,$10,$01
TileMapRow24
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$01,$11,$01
TileMapRow25
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$01,$11
TileMapRow26
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$11
TileMapRow27
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$11
TileMapRow28
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01
TileMapRow29
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01
TileMapRow30
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01

	align 256

TileMapRow31
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01
TileMapRow32
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$01,$10,$00,$00,$00,$00,$01
TileMapRow33
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$11,$00,$00,$00,$00,$01
TileMapRow34
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$01
TileMapRow35
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$01,$10,$00,$00,$00,$01
TileMapRow36
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$11,$00,$00,$00,$01
TileMapRow37
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$01,$10,$00,$00,$01
TileMapRow38
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$11,$00,$00,$01
TileMapRow39
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$01,$10,$00,$01
TileMapRow40
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$11,$00,$11

	align 256
	
TileMapRow41
	.byte $10,$00,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$00,$00,$00,$00,$00,$00,$00,$00,$00,$01,$11,$11
TileMapRow42
	.byte $11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11,$11
	
TileRowLookupTable
	.word TileMapRow1+4,TileMapRow2+4,TileMapRow3+4,TileMapRow4+4,TileMapRow5+4,TileMapRow6+4
	.word TileMapRow7+4,TileMapRow8+4,TileMapRow9+4,TileMapRow10+4,TileMapRow11+4,TileMapRow12+4,TileMapRow13+4
	.word TileMapRow14+4,TileMapRow15+4,TileMapRow16+4,TileMapRow17+4,TileMapRow18+4,TileMapRow19+4
	.word TileMapRow20+4,TileMapRow21+4,TileMapRow22+4,TileMapRow23+4,TileMapRow24+4,TileMapRow25+4
	.word TileMapRow26+4,TileMapRow27+4,TileMapRow28+4,TileMapRow29+4,TileMapRow30+4,TileMapRow31+4
	.word TileMapRow32+4,TileMapRow33+4,TileMapRow34+4,TileMapRow35+4,TileMapRow36+4,TileMapRow37+4
	.word TileMapRow38+4,TileMapRow39+4,TileMapRow40+4,TileMapRow41+4,TileMapRow42+4



;--tile lookup tables
	;--left tile is on vert axis, right tile on hor
;--normal versions
NormalTileTable
	.word GrassGrassNormalBitmap,GrassWaterNormalBitmap,0,0,0,0,0,0
	.word WaterGrassNormalBitmap,WaterWaterNormalBitmap,0,0,0,0,0,0

;--reversed versions
ReversedTileTable
	.word GrassGrassReversedBitmap,GrassWaterReversedBitmap,0,0,0,0,0,0
	.word WaterGrassReversedBitmap,WaterWaterReversedBitmap,0,0,0,0,0,0
;---Tile-Pair Bitmaps -- Normal (for PF1 and PF3)

	align 256

WaterGrassNormalBitmap
        .byte #%00000010;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000100;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00001001;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000010;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00001000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000001;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
WaterGrassReversedBitmap
        .byte #%01000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00100000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%10010000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%01000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00010000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%10000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
GrassWaterReversedBitmap
        .byte #%00000100;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000010;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00001001;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000100;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000001;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00001000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
        .byte #%00000000;$4A
        .byte #%11110000;$8A
        .byte #%00001111;$BA
GrassWaterNormalBitmap
        .byte #%00100000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%01000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%10010000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00100000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%10000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00010000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA
        .byte #%00000000;$4A
        .byte #%00001111;$8A
        .byte #%11110000;$BA

GrassGrassNormalBitmap
        .byte #%00100010;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%01000010;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%10011001;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00100010;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00000000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%10001000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00010001;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00000000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA





	
WaterWaterNormalBitmap
WaterWaterReversedBitmap
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000
	.byte %00000000
	.byte %11111111
	.byte %00000000

;---Tile-Pair Bitmaps -- Reversed (for PF2 and PF4)

GrassGrassReversedBitmap
        .byte #%01000100;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%01000010;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%10011001;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%01000100;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00000000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00010001;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%10001000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA
        .byte #%00000000;$4A
        .byte #%00000000;$8A
        .byte #%11111111;$BA



	



ColorTable
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3
	.byte COLOR1,COLOR2,COLOR3


	
OtherSpriteX
	.byte 0,8,17,25,33,41,48
	.byte 1,9,17,25,33,41,48
	.byte 2,10,18,26,34,42,48
	.byte 3,11,19,27,35,43,48
	.byte 4,12,20,28,36,44,48
	.byte 5,13,21,29,37,45,48
OtherSpriteType
	.byte 1,0,1,0,0,0,0
	.byte 0,0,0,0,0,0,0
	.byte 0,0,0,0,0,0,0
	.byte 0,0,0,0,0,0,0
	.byte 0,0,0,0,0,0,0
	.byte 0,0,0,0,0,0,0
OtherSpriteGfxLo
	.byte <PlayerFrame1,<BridgeSprite
OtherSpriteGfxHi
	.byte >PlayerFrame1,>BridgeSprite
	
	
BridgeSprite
        .byte #%00000000;--
        .byte #%10000001;--
        .byte #%10000001;--
        .byte #%11000011;--
        .byte #%11000011;--
        .byte #%11100111;--
        .byte #%10111101;--
        .byte #%10111101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%10100101;--
        .byte #%11100111;--
        .byte #%01100110;--
        .byte #%01100110;--
        .byte #%00111100;--
        .byte #%00011000;--
        .byte #%00000000;--
        .byte #%00000000;--
	
	
	
;-------------------------------------------------------------------------
;-------------------------End Data----------------------------------------
;-------------------------------------------------------------------------
	


;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
;--------------------------BANK TWO---------------------------------------
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
			
	; Bank 2 (2K)
	SEG	BANK2
	ORG	$1000,0
	RORG	$1800,0

	nop
	
	
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
;--------------------------SC HEADER--------------------------------------
;-------------------------------------------------------------------------
;-------------------------------------------------------------------------
	
	; Supercharger Header (8448 Bin Format)
	SEG	HEADER
	ORG	$2000,0

	; Start Address
	DC.W	Start
	; Bank Select Configuration
	; Bits 7-5 Write Pulse Delay	
	; Bits 4-2 Bank Config	
	;	000	3	ROM
	;	001	1	ROM
	;	010	3	1
	;	011	1	3
	;	100	3	ROM
	;	101	2	ROM
	;	110	3	2
	;	111	2	3
	; Bit 1 Write Enable (1=enable)
	; Bit 0 ROM power (1=on)
	DC.B	%00001010
	; Page Count, Checksum, and Multi-Load Index
	DC.B	$18, $55, 0
	; Progress Indicator (6K) 
	DC.W	$0224

	; Bank Offsets
	ORG	($2010),0

	DC.B	$02,$06,$0A,$0E,$12,$16,$1A,$1E		; Bank 3 	
	DC.B	$00,$04,$08,$0C,$10,$14,$18,$1C		; Bank 1 
	DC.B	$01,$05,$09,$0D,$11,$15,$19,$1D		; Bank 2 

	; Bank Checksums
	ORG	($2030),0
	
	DC.B	$55,$55,$55,$55,$55,$55,$55,$55		; Bank 3 
	DC.B	$55,$55,$55,$55,$55,$55,$55,$55		; Bank 1 
	DC.B	$55,$55,$55,$55,$55,$55,$55,$55		; Bank 2 

	; Padding To 8448 Bytes
	DS.B	184,0
